﻿using System.Data;
using System.Windows.Forms;
using MySql.Data.MySqlClient;


namespace cxyLib
{
    public class LinkMysql : ILinkDbBase
    {

        private MySqlConnection _conn;
        private DataTable _data;
        private MySqlDataAdapter _da;
        private MySqlCommandBuilder _cb;

        public void Connect( string connStr)
        {
            if (_conn != null)
                _conn.Close();

            try
            {
                _conn = new MySqlConnection(connStr);
                _conn.Open();
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("连接数据库失败: " + ex.Message);
            }
        }

        public string GetConStrFormat()
        {
            return "server={0};user id={1}; password={2}; database={3}; pooling=false";
        }


        public void GetDatabases(ComboBox databaseList)
        {
            MySqlDataReader reader = null;

            MySqlCommand cmd = new MySqlCommand("SHOW DATABASES", _conn);
            try
            {
                reader = cmd.ExecuteReader();
                databaseList.Items.Clear();
                while (reader.Read())
                {
                    databaseList.Items.Add(reader.GetString(0));
                }
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("枚举数据库失败: " + ex.Message);
            }
            finally
            {
                if (reader != null) reader.Close();
            }
        }

        public void GetTables(string databaseName, ComboBox tables)
        {
            MySqlDataReader reader = null;

            _conn.ChangeDatabase(databaseName);

            MySqlCommand cmd = new MySqlCommand("SHOW TABLES", _conn);
            try
            {
                reader = cmd.ExecuteReader();
                tables.Items.Clear();
                while (reader.Read())
                {
                    tables.Items.Add(reader.GetString(0));
                }
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("枚举mysql 列表失败 " + ex.Message);
            }
            finally
            {
                if (reader != null) reader.Close();
            }
        }
        /// <summary>
        /// 取出表中所有数据
        /// </summary>
        /// <param name="tablesname">表名</param>
        /// <returns></returns>
        public DataTable GetTablesData( string tablesname)
        {

            _data = new DataTable();
            _da = new MySqlDataAdapter("SELECT * FROM " + tablesname, _conn);
            _cb = new MySqlCommandBuilder(_da);
            _da.Fill(_data);
            return _data;
        }

        public void UpdateData(DataTable dt)
        {
            _da.Update(dt);
            _data.AcceptChanges();
        }

        public int ExecuteNonQuery(string queryString)
        {
            MySqlCommand cmd = new MySqlCommand(queryString,_conn);
            cmd.CommandType = CommandType.Text;

            try
            {
               return  cmd.ExecuteNonQuery();
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("执行NonQuery 失败, " + ex.Message);
            }
            return 0;
        }

        public IDataReader ExecuteReader(string queryString)
        {
            MySqlCommand cmd = new MySqlCommand(queryString, _conn);
            cmd.CommandType = CommandType.Text;
            IDataReader _thereader = null;

            try
            {
                _thereader= cmd.ExecuteReader(CommandBehavior.CloseConnection);
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("执行NonQuery 失败, " + ex.Message);
            }
            return _thereader;

        }

    }
}
